==> localnews-base-model-1.3.0.2-sources.jar: com/bxm/localnews/common/vo/LocationRelation.java <==
package com.bxm.localnews.common.vo;

import java.io.Serializable;
import java.util.Date;

/**
 * c_location_relation
 * @author 
 */
public class LocationRelation implements Serializable {
    /**
     * 主键
     */
    private Long id;

    /**
     * 关联内容（微信分享语、朋友圈分享语）
     */
    private String content;

    /**
     * 类型（1、微信分享语，2：朋友圈分享语）
     */
    private Byte type;

    /**
     * 创建时间
     */
    private Date createTime;

    /**
     * 地区编号
     */
    private String locationCode;

    /**
     * 分享次数
     */
    private Integer shareTime;

    public Integer getShareTime() {
        return shareTime;
    }

    public void setShareTime(Integer shareTime) {
        this.shareTime = shareTime;
    }

    private static final long serialVersionUID = 1L;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public Byte getType() {
        return type;
    }

    public void setType(Byte type) {
        this.type = type;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getLocationCode() {
        return locationCode;
    }

    public void setLocationCode(String locationCode) {
        this.locationCode = locationCode;
    }
}

==> localnews-base-model-2.0.1-20190414.113554-1-sources.jar: com/bxm/localnews/common/vo/LocationRelation.java <==
package com.bxm.localnews.common.vo;

import java.io.Serializable;
import java.util.Date;

/**
 * c_location_relation
 *
 * @author
 */
public class LocationRelation implements Serializable {
    private static final long serialVersionUID = 1L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 关联内容（微信分享语、朋友圈分享语）
     */
    private String content;

    /**
     * 类型（1、微信分享语，2：朋友圈分享语）
     */
    private Byte type;

    /**
     * 创建时间
     */
    private Date createTime;

    /**
     * 地区编号
     */
    private String locationCode;

    /**
     * 分享次数
     */
    private Integer shareTime;

    /**
     * 分享图片
     */
    private String imgUrl;

    public Integer getShareTime() {
        return shareTime;
    }

    public void setShareTime(Integer shareTime) {
        this.shareTime = shareTime;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public Byte getType() {
        return type;
    }

    public void setType(Byte type) {
        this.type = type;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public String getLocationCode() {
        return locationCode;
    }

    public void setLocationCode(String locationCode) {
        this.locationCode = locationCode;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }
}
